@@ -111,24 +111,27 @@ static void   gnome_canvas_line_render      (GnomeCanvasItem *item, GnomeCanvasB
 static GnomeCanvasItemClass *parent_class;
 
 
-GtkType
+GType
 gnome_canvas_line_get_type (void)
 {
-	static GtkType line_type = 0;
+	static GType line_type;
 
 	if (!line_type) {
-		GtkTypeInfo line_info = {
-			"GnomeCanvasLine",
-			sizeof (GnomeCanvasLine),
+		static const GTypeInfo object_info = {
 			sizeof (GnomeCanvasLineClass),
-			(GtkClassInitFunc) gnome_canvas_line_class_init,
-			(GtkObjectInitFunc) gnome_canvas_line_init,
-			NULL, /* reserved_1 */
-			NULL, /* reserved_2 */
-			(GtkClassInitFunc) NULL
+			(GBaseInitFunc) NULL,
+			(GBaseFinalizeFunc) NULL,
+			(GClassInitFunc) gnome_canvas_line_class_init,
+			(GClassFinalizeFunc) NULL,
+			NULL,			/* class_data */
+			sizeof (GnomeCanvasLine),
+			0,			/* n_preallocs */
+			(GInstanceInitFunc) gnome_canvas_line_init,
+			NULL			/* value_table */
 		};
 
-		line_type = gtk_type_unique (gnome_canvas_item_get_type (), &line_info);
+		line_type = g_type_register_static (GNOME_TYPE_CANVAS_ITEM, "GnomeCanvasLine",
+						    &object_info, 0);
 	}
 
 	return line_type;
@@ -145,7 +148,7 @@ gnome_canvas_line_class_init (GnomeCanvasLineClass *class)
 	object_class = (GtkObjectClass *) class;
 	item_class = (GnomeCanvasItemClass *) class;
 
-	parent_class = gtk_type_class (gnome_canvas_item_get_type ());
+	parent_class = g_type_class_peek_parent (class);
 
 	gobject_class->set_property = gnome_canvas_line_set_property;
 	gobject_class->get_property = gnome_canvas_line_get_property;
@@ -872,7 +875,6 @@ gnome_canvas_line_get_property (GObject              *object,
 				GParamSpec           *pspec)
 {
 	GnomeCanvasLine *line;
-	GdkColor *color;
 
 	g_return_if_fail (object != NULL);
 	g_return_if_fail (GNOME_IS_CANVAS_LINE (object));
@@ -893,13 +895,12 @@ gnome_canvas_line_get_property (GObject              *object,
 		break;
 
 	case PROP_FILL_COLOR_GDK: {
-		GdkColormap *colormap;
+		GnomeCanvas *canvas = GNOME_CANVAS_ITEM (line)->canvas;
+		GdkColormap *colormap = gtk_widget_get_colormap (GTK_WIDGET (canvas));
+		GdkColor color;
 
-		color = g_new (GdkColor, 1);
-		color->pixel = line->fill_pixel;
-		colormap = gtk_widget_get_colormap (GTK_WIDGET (line->item.canvas));
-		gdk_rgb_find_color (colormap, color);
-		g_value_set_boxed (value, color);
+		gdk_colormap_query_color (colormap, line->fill_pixel, &color);
+		g_value_set_boxed (value, &color);
 		break;
 	}
 
@@ -1071,14 +1072,14 @@ gnome_canvas_line_update (GnomeCanvasItem *item, double *affine, ArtSVP *clip_pa
 
 		gnome_canvas_item_update_svp_clip (item, &line->fill_svp, svp, clip_path);
 
-		if (line->first_arrow)
+		if (line->first_arrow && line->first_coords)
 			svp = svp_from_points (line->first_coords, NUM_ARROW_POINTS, affine);
 		else
 			svp = NULL;
 
 		gnome_canvas_item_update_svp_clip (item, &line->first_svp, svp, clip_path);
 
-		if (line->last_arrow)
+		if (line->last_arrow && line->last_coords)
 			svp = svp_from_points (line->last_coords, NUM_ARROW_POINTS, affine);
 		else
 			svp = NULL;
