@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * $Id: gnome-canvas-text.c,v 1.79 2002/01/09 06:08:07 timj Exp $
+ * $Id: gnome-canvas-text.c,v 1.82 2002/04/18 07:44:45 federico Exp $
  * Copyright (C) 1997, 1998, 1999, 2000 Free Software Foundation
  * All rights reserved.
  *
@@ -155,24 +155,27 @@ static GnomeCanvasItemClass *parent_class;
  * 
  * Return value: The type ID of the &GnomeCanvasText class.
  **/
-GtkType
+GType
 gnome_canvas_text_get_type (void)
 {
-	static GtkType text_type = 0;
+	static GType text_type;
 
 	if (!text_type) {
-		GtkTypeInfo text_info = {
-			"GnomeCanvasText",
-			sizeof (GnomeCanvasText),
+		static const GTypeInfo object_info = {
 			sizeof (GnomeCanvasTextClass),
-			(GtkClassInitFunc) gnome_canvas_text_class_init,
-			(GtkObjectInitFunc) gnome_canvas_text_init,
-			NULL, /* reserved_1 */
-			NULL, /* reserved_2 */
-			(GtkClassInitFunc) NULL
+			(GBaseInitFunc) NULL,
+			(GBaseFinalizeFunc) NULL,
+			(GClassInitFunc) gnome_canvas_text_class_init,
+			(GClassFinalizeFunc) NULL,
+			NULL,			/* class_data */
+			sizeof (GnomeCanvasText),
+			0,			/* n_preallocs */
+			(GInstanceInitFunc) gnome_canvas_text_init,
+			NULL			/* value_table */
 		};
 
-		text_type = gtk_type_unique (gnome_canvas_item_get_type (), &text_info);
+		text_type = g_type_register_static (GNOME_TYPE_CANVAS_ITEM, "GnomeCanvasText",
+						    &object_info, 0);
 	}
 
 	return text_type;
@@ -190,7 +193,7 @@ gnome_canvas_text_class_init (GnomeCanvasTextClass *class)
 	object_class = (GtkObjectClass *) class;
 	item_class = (GnomeCanvasItemClass *) class;
 
-	parent_class = gtk_type_class (gnome_canvas_item_get_type ());
+	parent_class = g_type_class_peek_parent (class);
 
 	gobject_class->set_property = gnome_canvas_text_set_property;
 	gobject_class->get_property = gnome_canvas_text_get_property;
@@ -786,6 +789,9 @@ gnome_canvas_text_set_property (GObject            *object,
 			pango_context_set_language (context, language);
 			pango_context_set_base_dir (context,
 						    pango_context_get_base_dir (gtk_context));
+			pango_context_set_font_description (context,
+							    pango_context_get_font_description (gtk_context));
+			
 		} else
 			context = gtk_context;
 			
@@ -1099,7 +1105,6 @@ gnome_canvas_text_get_property (GObject            *object,
 				GParamSpec         *pspec)
 {
 	GnomeCanvasText *text;
-	GdkColor *color;
 
 	g_return_if_fail (object != NULL);
 	g_return_if_fail (GNOME_IS_CANVAS_TEXT (object));
@@ -1262,13 +1267,12 @@ gnome_canvas_text_get_property (GObject            *object,
 		break;
 
 	case PROP_FILL_COLOR_GDK: {
-		GdkColormap *colormap;
+		GnomeCanvas *canvas = GNOME_CANVAS_ITEM (text)->canvas;
+		GdkColormap *colormap = gtk_widget_get_colormap (GTK_WIDGET (canvas));
+		GdkColor color;
 
-		color = g_new (GdkColor, 1);
-		color->pixel = text->pixel;
-		colormap = gtk_widget_get_colormap (GTK_WIDGET (text->item.canvas));
-		gdk_rgb_find_color (colormap, color);
-		g_value_set_boxed (value, color);
+		gdk_colormap_query_color (colormap, text->pixel, &color);
+		g_value_set_boxed (value, &color);
 		break;
 	}
 	case PROP_FILL_COLOR_RGBA:
